VideoInterop.Binary (video_interop v0.1.0)

Copy Markdown View Source

BEAM-owned binary video frame storage.

The binary is immutable and owned by the frame term, so this storage does not require a VideoInterop.Lease. planes describes offsets and row strides inside data.

Summary

Types

t()

@type t() :: %VideoInterop.Binary{
  data: binary(),
  planes: [VideoInterop.Binary.Plane.t()]
}